Crate luct_client

Crate luct_client 

Modules

deduplication
Client wrapper to deduplicate requests to the same Url
reqwest
Implementation of the Client trait using reqwest

Structs

CtClient
Wrapper around Client, that implements fetching and validation logic

Enums

ClientError
Error returned by Client implementation when a request fails

Traits

Client
Backend client implementation trait