pub struct RequestDeduplicationClient<C> { /* private fields */ }Expand description
Wraps an inner Client and deduplicates running requests.
The endpoint must be idempotent. In particular, the following things must be guaranteed:
- The endpoint must return the same response on the same request
- The deduplication may fail due to TOCTOU, and sending the same request twice must not change the servers behavioru
Implementations
Sourceimpl<C> RequestDeduplicationClient<C>
impl<C> RequestDeduplicationClient<C>