pub enum ClientError {
UnsupportedVersion,
JsonError {
line: usize,
column: usize,
},
SignatureValidationFailed(&'static str, SignatureValidationError),
ConsistencyProofError(ProofValidationError),
AuditProofError(ProofValidationError),
ConnectionError(String),
ConnectionErrorStd(Arc<dyn Error + Send + Sync>),
ResponseError {
url: String,
code: u16,
msg: String,
},
Checkpoint(ParseCheckpointError),
TilingError(TilingError),
SthError,
}Expand description
Error returned by Client implementation when a request fails
Variants
UnsupportedVersion
A client attempted to make a request, that is not supported by a log with this version
JsonError
A request was returned but the client failed to parse the JSON in the resonse
SignatureValidationFailed(&'static str, SignatureValidationError)
Verification of a signature failed
ConsistencyProofError(ProofValidationError)
Validating a consistency proof failed
AuditProofError(ProofValidationError)
Validating an audit proof failed
ConnectionError(String)
The connection failed
ConnectionErrorStd(Arc<dyn Error + Send + Sync>)
The connection failed
ResponseError
The request failed, the server returned a response code other than 200
Checkpoint(ParseCheckpointError)
Failed to parse a checkpoint note
TilingError(TilingError)
An error specific to the tiling API occured
SthError
The STH could not be parsed